@@ -14,7 +14,7 @@
 #include "networkstatus.h"
 
 #include "appletproxymodel.h"
-#include "configuration.h"
+#include "configurationproxy.h"
 #include "creatableconnectionsmodel.h"
 #include "editorproxymodel.h"
 #include "kcmidentitymodel.h"
@@ -51,9 +51,9 @@ void QmlPlugins::registerTypes(const char *uri)
     // @uri org.kde.plasma.networkmanagement.MobileProxyModel
     qmlRegisterType<MobileProxyModel>(uri, 0, 2, "MobileProxyModel");
 
-    qmlRegisterSingletonType<Configuration>(uri, 0, 2, "Configuration", [](QQmlEngine *engine, QJSEngine *scriptEngine) -> QObject * {
+    qmlRegisterSingletonType<ConfigurationProxy>(uri, 0, 2, "Configuration", [](QQmlEngine *engine, QJSEngine *scriptEngine) -> QObject * {
         Q_UNUSED(engine)
         Q_UNUSED(scriptEngine)
-        return new Configuration;
+        return new ConfigurationProxy;
     });
 }
