@@ -69,7 +69,7 @@ void MobileConnectionWizard::initializePage(int id)
         if (country.isEmpty())
             mCountryList->setCurrentRow(0);
         else {
-            QList<QListWidgetItem *> items = mCountryList->findItems(mProviders->getCountryName(country), Qt::MatchExactly);
+            const QList<QListWidgetItem *> items = mCountryList->findItems(mProviders->getCountryName(country), Qt::MatchExactly);
             if (!items.empty()) {
                 mCountryList->setCurrentItem(items.first());
             }
@@ -126,7 +126,7 @@ void MobileConnectionWizard::initializePage(int id)
         break;
 
     case 3: // Plans Page
-        disconnect(mPlanComboBox, QOverload<const QString &>::of(&KComboBox::currentIndexChanged), this, &MobileConnectionWizard::slotEnablePlanEditBox);
+        disconnect(mPlanComboBox, QOverload<int>::of(&KComboBox::currentIndexChanged), this, &MobileConnectionWizard::slotEnablePlanEditBox);
         mPlanComboBox->clear();
         if (type() != NetworkManager::ConnectionSettings::Gsm) {
             goto OUT_3;
@@ -153,9 +153,9 @@ void MobileConnectionWizard::initializePage(int id)
             mPlanComboBox->addItem(i18nc("Mobile Connection Wizard", "My plan is not listed…"));
         }
         mPlanComboBox->setCurrentIndex(0);
-        slotEnablePlanEditBox(mPlanComboBox->currentText());
+        slotEnablePlanEditBox(mPlanComboBox->currentIndex());
     OUT_3:
-        connect(mPlanComboBox, QOverload<const QString &>::of(&KComboBox::currentIndexChanged), this, &MobileConnectionWizard::slotEnablePlanEditBox);
+        connect(mPlanComboBox, QOverload<int>::of(&KComboBox::currentIndexChanged), this, &MobileConnectionWizard::slotEnablePlanEditBox);
         break;
 
     case 4: // Confirm Page
@@ -232,22 +232,22 @@ QVariantList MobileConnectionWizard::args()
 
 QWizardPage *MobileConnectionWizard::createIntroPage()
 {
-    QWizardPage *page = new QWizardPage();
+    auto page = new QWizardPage();
     page->setTitle(i18nc("Mobile Connection Wizard", "Set up a Mobile Broadband Connection"));
-    QVBoxLayout *layout = new QVBoxLayout;
+    auto layout = new QVBoxLayout;
 
-    QLabel *label =
+    auto label =
         new QLabel(i18nc("Mobile Connection Wizard", "This assistant helps you easily set up a mobile broadband connection to a cellular (3G) network."));
     label->setWordWrap(true);
     layout->addWidget(label);
 
-    label = new QLabel('\n' + i18nc("Mobile Connection Wizard", "You will need the following information:"));
+    label = new QLabel(QLatin1Char('\n') + i18nc("Mobile Connection Wizard", "You will need the following information:"));
     layout->addWidget(label);
 
-    label = new QLabel(QString("  . %1\n  . %2\n  . %3")
-                           .arg(i18nc("Mobile Connection Wizard", "Your broadband provider's name"))
-                           .arg(i18nc("Mobile Connection Wizard", "Your broadband billing plan name"))
-                           .arg(i18nc("Mobile Connection Wizard", "(in some cases) Your broadband billing plan APN (Access Point Name)")));
+    label = new QLabel(QStringLiteral("  . %1\n  . %2\n  . %3")
+                           .arg(i18nc("Mobile Connection Wizard", "Your broadband provider's name"),
+                                i18nc("Mobile Connection Wizard", "Your broadband billing plan name"),
+                                i18nc("Mobile Connection Wizard", "(in some cases) Your broadband billing plan APN (Access Point Name)")));
     layout->addWidget(label);
 
     if (!mInitialMethodType) {
@@ -284,7 +284,7 @@ void MobileConnectionWizard::introAddDevice(const NetworkManager::Device::Ptr &d
         ModemManager::Modem::Ptr modemInterface = modem->interface(ModemManager::ModemDevice::ModemInterface).objectCast<ModemManager::Modem>();
         if (modemInterface->powerState() == MM_MODEM_POWER_STATE_ON) {
             desc.append(modemInterface->manufacturer());
-            desc.append(" ");
+            desc.append(QLatin1Char(' '));
             desc.append(modemInterface->model());
         } else {
             QString deviceName = modemInterface->device();
@@ -292,7 +292,7 @@ void MobileConnectionWizard::introAddDevice(const NetworkManager::Device::Ptr &d
                 if (d.udi().contains(deviceName, Qt::CaseInsensitive)) {
                     deviceName = d.product();
                     if (!deviceName.startsWith(d.vendor())) {
-                        deviceName = d.vendor() + ' ' + deviceName;
+                        deviceName = d.vendor() + QLatin1Char(' ') + deviceName;
                     }
                     desc.append(deviceName);
                     break;
@@ -396,11 +396,11 @@ void MobileConnectionWizard::introRemoveAllDevices()
 
 QWizardPage *MobileConnectionWizard::createCountryPage()
 {
-    QWizardPage *page = new QWizardPage();
+    auto page = new QWizardPage();
     page->setTitle(i18nc("Mobile Connection Wizard", "Choose your Provider's Country"));
-    QVBoxLayout *layout = new QVBoxLayout;
+    auto layout = new QVBoxLayout;
 
-    QLabel *label = new QLabel(i18nc("Mobile Connection Wizard", "Country List:"));
+    auto label = new QLabel(i18nc("Mobile Connection Wizard", "Country List:"));
     layout->addWidget(label);
 
     mCountryList = new QListWidget();
@@ -419,9 +419,9 @@ QWizardPage *MobileConnectionWizard::createCountryPage()
 
 QWizardPage *MobileConnectionWizard::createProvidersPage()
 {
-    QWizardPage *page = new QWizardPage();
+    auto page = new QWizardPage();
     page->setTitle(i18nc("Mobile Connection Wizard", "Choose your Provider"));
-    QVBoxLayout *layout = new QVBoxLayout;
+    auto layout = new QVBoxLayout;
 
     radioAutoProvider = new QRadioButton(i18nc("Mobile Connection Wizard", "Select your provider from a &list:"));
     radioAutoProvider->setChecked(true);
@@ -473,11 +473,11 @@ void MobileConnectionWizard::slotCheckProviderList()
 
 QWizardPage *MobileConnectionWizard::createPlansPage()
 {
-    QWizardPage *page = new QWizardPage();
+    auto page = new QWizardPage();
     page->setTitle(i18nc("Mobile Connection Wizard", "Choose your Billing Plan"));
-    QBoxLayout *layout = new QBoxLayout(QBoxLayout::TopToBottom);
+    auto layout = new QBoxLayout(QBoxLayout::TopToBottom);
 
-    QLabel *label = new QLabel(i18nc("Mobile Connection Wizard", "&Select your plan:"));
+    auto label = new QLabel(i18nc("Mobile Connection Wizard", "&Select your plan:"));
     layout->addWidget(label);
 
     mPlanComboBox = new KComboBox();
@@ -492,7 +492,7 @@ QWizardPage *MobileConnectionWizard::createPlansPage()
     label->setBuddy(userApn);
     layout->addWidget(userApn);
 
-    QHBoxLayout *layout2 = new QHBoxLayout();
+    auto layout2 = new QHBoxLayout();
     label = new QLabel();
     label->setPixmap(QIcon::fromTheme(QStringLiteral("dialog-warning")).pixmap(32));
     layout2->addWidget(label, 0, Qt::AlignTop);
@@ -501,7 +501,7 @@ QWizardPage *MobileConnectionWizard::createPlansPage()
                              "you are unsure of your plan please ask your provider for your plan's APN."));
     label->setWordWrap(true);
     layout2->addWidget(label);
-    layout->addWidget(new QLabel(""));
+    layout->addWidget(new QLabel());
     layout->addLayout(layout2);
 
     page->setLayout(layout);
@@ -509,8 +509,9 @@ QWizardPage *MobileConnectionWizard::createPlansPage()
     return page;
 }
 
-void MobileConnectionWizard::slotEnablePlanEditBox(const QString &text)
+void MobileConnectionWizard::slotEnablePlanEditBox(int index)
 {
+    const QString text = mPlanComboBox->itemText(index);
     if (type() != NetworkManager::ConnectionSettings::Gsm) {
         return;
     }
@@ -535,11 +536,11 @@ void MobileConnectionWizard::slotEnablePlanEditBox(const QString &text)
 
 QWizardPage *MobileConnectionWizard::createConfirmPage()
 {
-    QWizardPage *page = new QWizardPage();
+    auto page = new QWizardPage();
     page->setTitle(i18nc("Mobile Connection Wizard", "Confirm Mobile Broadband Settings"));
-    QVBoxLayout *layout = new QVBoxLayout;
+    auto layout = new QVBoxLayout;
 
-    QLabel *label = new QLabel(i18nc("Mobile Connection Wizard", "Your mobile broadband connection is configured with the following settings:"));
+    auto label = new QLabel(i18nc("Mobile Connection Wizard", "Your mobile broadband connection is configured with the following settings:"));
     label->setWordWrap(true);
     layout->addWidget(label);
 
@@ -548,7 +549,7 @@ QWizardPage *MobileConnectionWizard::createConfirmPage()
     labelProvider = new QLabel();
     layout->addWidget(labelProvider);
 
-    labelPlanLabel = new QLabel('\n' + i18nc("Mobile Connection Wizard", "Your Plan:"));
+    labelPlanLabel = new QLabel(QLatin1Char('\n') + i18nc("Mobile Connection Wizard", "Your Plan:"));
     layout->addWidget(labelPlanLabel);
     labelPlan = new QLabel();
     layout->addWidget(labelPlan);
